@@ -1,7 +1,11 @@
 import unittest
 import datetime
+from uuid import uuid4
 
 from arangodb.api import Client, Database, Collection, Document
+from arangodb.index.api import Index
+from arangodb.index.general import FulltextIndex, CapConstraintIndex
+from arangodb.index.unique import HashIndex, SkiplistIndex, GeoIndex
 from arangodb.orm.fields import CharField, ForeignKeyField, NumberField, DatetimeField, DateField, BooleanField
 from arangodb.orm.models import CollectionModel
 from arangodb.query.advanced import Query, Traveser
@@ -501,6 +505,50 @@ class CollectionModelManagerTestCase(unittest.TestCase):
     def tearDown(self):
         Database.remove(name=self.database_name)
 
+    def test_retrieve_one_specific_model_by_char(self):
+
+        class TestModel(CollectionModel):
+            uuid = CharField(null=False)
+
+        TestModel.init()
+
+        model1 = TestModel()
+        model1.uuid = str(uuid4())
+        model1.save()
+
+        model2 = TestModel()
+        model2.uuid = str(uuid4())
+        model2.save()
+
+        specific_model = TestModel.objects.get(uuid=model2.uuid)
+
+        self.assertEqual(specific_model.uuid, model2.uuid)
+
+        TestModel.destroy()
+
+    def test_retrieve_one_specific_model_by_bool(self):
+
+        class TestModel(CollectionModel):
+            active = BooleanField(null=False)
+
+        TestModel.init()
+
+        model1 = TestModel()
+        model1.active = False
+        model1.save()
+
+        model2 = TestModel()
+        model2.active = True
+        model2.save()
+
+        specific_model1 = TestModel.objects.get(active=model1.active)
+        specific_model2 = TestModel.objects.get(active=model2.active)
+
+        self.assertEqual(specific_model1.document.id, model1.document.id)
+        self.assertEqual(specific_model2.document.id, model2.document.id)
+
+        TestModel.destroy()
+
     def test_retrieve_all_models(self):
 
         class TestModel(CollectionModel):
@@ -895,16 +943,65 @@ class TransactionTestCase(ExtendedTestCase):
 class IndexTestCase(ExtendedTestCase):
     def setUp(self):
 
-        self.database_name = 'testcase_index_123'
+        self.database_name = 'testcase_index_222_123'
         self.db = Database.create(name=self.database_name)
 
-        self.operating_collection = 'foo_test'
+        self.operating_collection = 'bar_extra'
         self.test_1_col = Collection.create(name=self.operating_collection)
 
     def tearDown(self):
         Collection.remove(name=self.operating_collection)
         Database.remove(name=self.database_name)
 
+    def test_unique_hash_index(self):
+
+        index = Index(self.test_1_col, HashIndex(fields=[
+            'username'
+        ]))
+
+        index.save()
+
+        index.delete()
+
+    def test_unique_skiptlist_index(self):
+
+        index = Index(self.test_1_col, SkiplistIndex(fields=[
+            'username'
+        ]))
+
+        index.save()
+
+        index.delete()
+
+    def test_unique_geo_index(self):
+
+        index = Index(self.test_1_col, GeoIndex(fields=[
+            'position'
+        ], geo_json=True
+        ))
+
+        index.save()
+
+        index.delete()
+
+    def test_fulltext_index(self):
+
+        index = Index(self.test_1_col, FulltextIndex(fields=[
+            'description'
+        ], minimum_length=5))
+
+        index.save()
+
+        index.delete()
+
+    def test_cap_constraint_index(self):
+
+        index = Index(self.test_1_col, CapConstraintIndex(size=5))
+
+        index.save()
+
+        index.delete()
+
 
 class UserTestCase(ExtendedTestCase):
     def setUp(self):
